@@ -17,20 +17,20 @@
 
       compno1 = 0
       compno2 = 0
-      do i = Det%nct, 1, -1
-         modif = Det%cmp(i)%modifier
-         mn = Det%Cn2media(i)
+      do i = Det.nct, 1, -1
+         modif = Det.cmp(i).modifier
+         mn = Det.Cn2media(i)
          if(modif > 0 .or. 
-     *      Media(mn)%Birks /= " ") then
+     *      Media(mn).Birks /= " ") then
             compno2 =  i
             exit
          endif
       enddo
-      do i = 1, Det%nct
-         modif = Det%cmp(i)%modifier
-         mn = Det%Cn2media(i)
+      do i = 1, Det.nct
+         modif = Det.cmp(i).modifier
+         mn = Det.Cn2media(i)
          if(modif > 0 .or. 
-     *      Media(mn)%Birks /= " ") then
+     *      Media(mn).Birks /= " ") then
             compno1 =  i
             exit
          endif
