@@ -336,14 +336,16 @@ c       * process for the events
 
       write(0, *)
      *  ' ***************** You made it! **************'
+      write(0,*)
+     *  ' If you have already done mkdrawconfig and drawconfig '
+      write(0,*)
+     *  ' and  finished "make data for display", then'
       write(0, *)
      *   ' You can now display the trace of particles   '
       write(0, *) 
      *   ' together with the detector configuration: By'
-      write(0, *)
-     *   '1) Geomview: Goto Util/Geomview and'
       write(0,*) 
-     * ' ./disptracebygeomv tracedatapath det'
+     * ' disptracebygeomv "tracedatapath" det'
       write(0, *) 
      *   '2) Gnuplot: Go to Util and enter gnuplot. '
       write(0, *)
