@@ -1,5 +1,6 @@
       implicit none
 #include "Zmedia.h"
+#include "ZepTrackp.h"
       record /epmedia/media
       integer::icon, how
       character(100)::file
@@ -12,6 +13,7 @@ c        < LPM region
 c           pair
       call epCrePrSTbl1(media, media.cnst)
 c           pair LPM
+      LPMeffect =.true.
       call epCrePrSTblH(media, media.cnst)
       end
 
