@@ -8,22 +8,24 @@
       integer i, io
       real*8 Ee, prob, Eg, path, Ek 
       character*30 file
-      character*16 name
-      integer  nevent, dummy, seed(2)
+      character*24 name
+      real(4):: rhoc
+      integer  nevent, dummy, seed(2), posast
 
 c      EpartialSC = 0.1  ! for test  ( Seltzer region max
 c                        is lowered to this Ee)
       dummy = 9876531
       io = 10
       read(*, *) nevent, Ek, name, LPMeffect, Flpm
-      file = "../../../Data/Media/"//name 
+      call getRhoc(name, name, rhoc)
+      file =  "../../../Data/Media/"//trim(name)
       call cerrorMsg(file,  1)
 
       Ee = Ek + masele
       
       open(io, file=file, action='read' ) 
       call epReadTab(io, media)
-
+      media.rhoc = rhoc
 
       write(0,*) '# "Eg/Ek" "log10(//)" "sampled path(r.l)" '//
      *        ' " prob/r.l" "Ek"'    
