@@ -9,27 +9,27 @@ c
       integer i, io
       real*8 Ee, prob, Eg, path
       character*50 file
-      character*16 name
-
+      character*24 name
 
+      real(4):: rhoc
       integer  nevent, dummy, seed(2)
 
       dummy = 9876533
 
       io = 10
       read(*, *) nevent, Eg, name, LPMeffect
-      file = "../../../Data/Media/"//name 
+      call getRhoc(name, name, rhoc)
+      file = "../../../Data/Media/"//trim(name) 
       call cerrorMsg(file,  1)
 
       open(io, file=file, action='READ') 
       call epReadTab(io, media)
-
+      media.rhoc = rhoc
 
       write(0, '(a)') '# Ee/Eg (Ee-m)/(Eg-2m) sampled Path(r.l)'//
      *     ' prob/r.l'
       call  cmkSeed(dummy, seed)
       call rnd1i(seed)
-
       do i = 1,  nevent
          call epPrSampP(media, Eg, prob, path)
          call epPrSampE(media, Eg, Ee)
