@@ -3,7 +3,8 @@
 #include "Zmedia.h"
 #include "Zmass.h"
 #include "ZepTrackp.h"
-      type(epmedia):: media
+
+      record /epmedia/media
       integer i, io
       real*8 Emu, prob, Eg, path, Ek 
       character*90 file
@@ -29,7 +30,7 @@
 
       Emu = Ek + masmu
       call epReadTab(io, media)
-      call epMuBrEcheck(Emu, media)
+
 
       write(0,*) '# "Eg/Ek" "log10(//)" "sampled path(r.l)" '//
      *        ' " prob/r.l" "Ek"'    
@@ -43,3 +44,4 @@
      *       log10(Eg/Ek), path, prob, Ek
       enddo
       end
+
