@@ -50,7 +50,7 @@ c       <<<<<<<<<<<<<<<<<<<<
         record /epmedia/FirstMedia  ! first collision media
         character*8  Proc1 ! to keep first interaction type
         record /epPos/ FirstInt !  to keep first int. pos.
-        					       
+        record /epTrack/FirstIntTrack ! to keep first int track ptcl
         record /ep3Vec/ Bfield   !  Bfield.x, y, z  the B in  Tesla
                                 !    in local coordinate 
         real*8   pathInB        !  total path length in B for a particle 
@@ -73,9 +73,9 @@ c
        common /ZepTrackv/ Media, FirstMedia,
      *  Incident, cTrack, Move, 
      *  Bfield, Efield,
-     *  FirstInt, MaxPath, Upsilon, Xai,  pathInB,
+     *  FirstInt, FirstIntTrack, MaxPath, Upsilon, Xai,  pathInB,
      *  Beta, Tcoefx, Tminx,  SumDe, Cn,  FirstCn,
-     *   MediaNo,  NoOfMedia, Ethin, Total1ryE,
+     *  MediaNo,  NoOfMedia, Ethin, Total1ryE,
      *  Firsti, FirstC, Bndryerr, cLcompNo, cPtyNo,
      *  CrossMode, ImperativeEmin, Making1ry
 
