@@ -1714,17 +1714,17 @@ c
       real*8 cosa, sina
       real*8  length
       
-      z1 = cmplx(x1, y1)
-      z2 = cmplx(x2, y2)
-      z3 = cmplx(x3, y3)
-      z4 = cmplx(x4, y4)
+      z1 = cmplx(x1, y1,8)
+      z2 = cmplx(x2, y2,8)
+      z3 = cmplx(x3, y3,8)
+      z4 = cmplx(x4, y4,8)
       length = abs(z4-z3)
       if( length .le. eps )  then
          icon = 2
       else
          cosa = (x4-x3)/length
          sina = (y4-y3)/length
-         expia = cmplx(cosa, sina)
+         expia = cmplx(cosa, sina,8)
          call kxplsl(z3, expia, z1 ,z2, eps, p, q, icon)
          if(icon  .eq. 0) then
 c             see if x-point is within z3-z4.
