@@ -40,10 +40,11 @@ c            or at the entrance of a  "light" component
 !        so  we make EntPC and ExtPC separately
       use modepLightCounter
       implicit none
+#include  "ZepMaxdef.h"
 #include  "ZepTrackv.h"
 
       type(photonc),intent(inout)::pcc(*)
-      character(len=16)::struc
+      character(len=MAX_STRUCCHR)::struc, basename  ! v9.164
 
 
 c///////////////
@@ -52,28 +53,29 @@ c///////////////
       endif
 c/////////////
       call epqstruc(Move.Track.cn, struc)
+      call epGetBaseStrucName(struc, basename)
       if( .not. allocated( pcc(cLcompNo)%pc )) then
-         if(struc(1:3) == 'box') then
+         if( basename == 'box') then
             allocate(  pcc(cLcompNo)%pc(1:2,1:6)  )
             allocate(  pcc(cLcompNo)%pct(1:6) )
             pcc(cLcompNo)%pc(:,:) = 0.
-         elseif(struc(1:7) == 'octagon') then
+         elseif( basename == 'octagon') then
             allocate(  pcc(cLcompNo)%pc(1:2,1:10)  )
             allocate(  pcc(cLcompNo)%pct(1:10) )
             pcc(cLcompNo)%pc(:,:) = 0.
-         elseif( struc(1:3) == 'cyl') then 
+         elseif( basename == 'cyl') then 
             allocate( pcc(cLcompNo)%pc(1:2,1:3)  )
             allocate( pcc(cLcompNo)%pct(1:3) )
             pcc(cLcompNo)%pc(:,:) = 0.
-         elseif( struc(1:4) == 'ecyl') then 
+         elseif( basename == 'ecyl') then 
             allocate( pcc(cLcompNo)%pc(1:2,1:3)  )
             allocate( pcc(cLcompNo)%pct(1:3) )
             pcc(cLcompNo)%pc(:,:) =0.
-         elseif( struc(1:4) == 'pipe') then 
+         elseif( basename == 'pipe') then 
             allocate( pcc(cLcompNo)%pc(1:2,1:4)  )
             allocate( pcc(cLcompNo)%pct(1:4) )
             pcc(cLcompNo)%pc(:,:) = 0.
-         elseif(struc(1:5) == 'prism') then
+         elseif( basename == 'prism') then
             allocate(  pcc(cLcompNo)%pc(1:2,1:5)  )
             allocate(  pcc(cLcompNo)%pct(1:5) )
             pcc(cLcompNo)%pc(:,:) = 0.
