@@ -1,12 +1,12 @@
       subroutine epxpLand4vp(p1, p2, p3, p4, a, b, l, icon, jcon)
       implicit none
 #include "ZepPos.h"
-!        get a crossing point of a half line with a plane formed
-!        by the 4 points on a plane. and judge if the x point 
-!        is inside of the "square" formed by p1,p2,p3,p4.
-       type(epPos)::  p1,p2,p3,p4 ! input.  
-       type(epPos)::  a  ! input.  starting point of the half line
-       type(epPos)::  b  ! input.  direction cos of the line |b| =1
+c        get a crossing point of a half line with a plane formed
+c        by the 4 points on a plane. and judge if the x point 
+c        is inside of the "square" formed by p1,p2,p3,p4.
+      record /epPos/ p1,p2,p3,p4 ! input.  
+      record /epPos/ a  ! input.  starting point of the half line
+      record /epPos/ b  ! input.  direction cos of the line |b| =1
       real*8  l         ! output. a+lb is the crossing point.
                         !        l may be negative
 
@@ -21,14 +21,14 @@
                     !         0: p is not on the vertex
                     !         i: p=pi (i=1~4)
 
-       type(epPos)::  n, p
+      record /epPos/ n, p
       real*8 k
       call ep3p2plane(p1, p2, p3, n, k)
       call epxpLandP(a, b, n, k, l, icon)
       if(icon .le. 2) then
-         p%x = a%x + b%x*l
-         p%y = a%y + b%y*l
-         p%z = a%z + b%z*l
+         p.x = a.x + b.x*l
+         p.y = a.y + b.y*l
+         p.z = a.z + b.z*l
          call episPin4(p1, p2, p3, p4, n, p, icon, jcon)
       else
          icon = 6
@@ -37,13 +37,13 @@
       subroutine epxpLand4vp2(p1, p2, p3, p4, a, b, n, k, l, icon, jcon)
       implicit none
 #include "ZepPos.h"
-!        get a crossing point of a half line with a plane 
-!        expressed by normal verctor and distance form origin to
-!        the plane. 
-       type(epPos)::  p1, p2, p3, p4 ! input. 4 points forming a plane
-       type(epPos)::  a  ! input.  starting point of the half line
-       type(epPos)::  b  ! input.  direction cos of the line |b| =1
-       type(epPos)::  n  ! input.  normal vector
+c        get a crossing point of a half line with a plane 
+c        expressed by normal verctor and distance form origin to
+c        the plane. 
+      record /epPos/ p1, p2, p3, p4 ! input. 4 points forming a plane
+      record /epPos/ a  ! input.  starting point of the half line
+      record /epPos/ b  ! input.  direction cos of the line |b| =1
+      record /epPos/ n  ! input.  normal vector
       real*8 k          ! input. scaler product of n and any
                         ! point on the plane.  (normally distance
                         ! from the origin to the plane
@@ -61,13 +61,13 @@
                     !         0: p is not on the vertex
                     !         i: p=pi (i=1~4)
 
-       type(epPos)::  p
+      record /epPos/ p
 
       call epxpLandP(a, b, n, k, l, icon)
       if(icon .le. 2) then
-         p%x = a%x + b%x*l
-         p%y = a%y + b%y*l
-         p%z = a%z + b%z*l
+         p.x = a.x + b.x*l
+         p.y = a.y + b.y*l
+         p.z = a.z + b.z*l
          call episPin4(p1, p2, p3, p4, n, p, icon, jcon)
       else
          icon = 6
@@ -76,12 +76,12 @@
       subroutine epxpLand3vp(p1, p2, p3, a, b, l, icon, jcon)
       implicit none
 #include "ZepPos.h"
-!        get a crossing point of a half line with a plane formed
-!        by the 3 points. and judge if the x point 
-!        is inside of the "triangle" formed by p1,p2,p3
-       type(epPos)::  p1,p2,p3 ! input.  
-       type(epPos)::  a  ! input.  starting point of the half line
-       type(epPos)::  b  ! input.  direction cos of the line |b| =1
+c        get a crossing point of a half line with a plane formed
+c        by the 3 points. and judge if the x point 
+c        is inside of the "triangle" formed by p1,p2,p3
+      record /epPos/ p1,p2,p3 ! input.  
+      record /epPos/ a  ! input.  starting point of the half line
+      record /epPos/ b  ! input.  direction cos of the line |b| =1
       real*8  l         ! output. a+lb is the crossing point.  l  >=0
                         !        
 
@@ -95,44 +95,44 @@
                     !         0: p is not on the vertex
                     !         i: p=pi (i=1~3)
 
-       type(epPos)::  n, p
+      record /epPos/ n, p
       real*8 k
 
       call ep3p2plane(p1, p2, p3, n, k)
       call epxpLandP(a, b, n, k, l, icon)
       if(icon .le. 2) then
-         p%x = a%x + b%x*l
-         p%y = a%y + b%y*l
-         p%z = a%z + b%z*l
+         p.x = a.x + b.x*l
+         p.y = a.y + b.y*l
+         p.z = a.z + b.z*l
          call episPin3(p1, p2, p3, n, p, icon, jcon)
-!
-!      integer icon  ! output. 0: p is inside of the triangle formed by p1,2,3.
-!                    !         1: p is on the line, p1-p2.
-!                    !         2: p is on the p2-p3  line
-!                    !         3: p is on the p3-p1 line. 
-!                    !         4: p is outside of the triangle.
-!     integer jcon  ! output. has meaning only if icon =1~3.
-!                    !         0--> the point is not on the vertex
-!                    !         1--> p = p1
-!                    !         2--> p = p2
-!                    !         3--> p = p3 
-!
+c
+c      integer icon  ! output. 0: p is inside of the triangle formed by p1,2,3.
+c                    !         1: p is on the line, p1-p2.
+c                    !         2: p is on the p2-p3  line
+c                    !         3: p is on the p3-p1 line. 
+c                    !         4: p is outside of the triangle.
+c     integer jcon  ! output. has meaning only if icon =1~3.
+c                    !         0--> the point is not on the vertex
+c                    !         1--> p = p1
+c                    !         2--> p = p2
+c                    !         3--> p = p3 
+c
       else
          icon = 5
       endif
       end
       subroutine epxpLand3vpB(p1, p2, p3, a, b, l, towhich, icon)
-!/////////////
-!      use sqTccl,only:check 
-!///////////
+c/////////////
+c      use sqTccl,only:check 
+c///////////
       implicit none
 #include "ZepPos.h"
-!        get a crossing point of a half line with a plane formed
-!        by the 3 points. and judge if the x point 
-!        is inside of the "triangle" formed by p1,p2,p3
-       type(epPos)::  p1,p2,p3 ! input.  
-       type(epPos)::  a  ! input.  starting point of the half line
-       type(epPos)::  b  ! input.  direction cos of the line |b| =1
+c        get a crossing point of a half line with a plane formed
+c        by the 3 points. and judge if the x point 
+c        is inside of the "triangle" formed by p1,p2,p3
+      record /epPos/ p1,p2,p3 ! input.  
+      record /epPos/ a  ! input.  starting point of the half line
+      record /epPos/ b  ! input.  direction cos of the line |b| =1
       real(8),intent(out):: l         ! output. a+lb is the crossing point.  l  >=0
                         !        
       real(8),intent(out):: towhich  ! scaler proc. of plane's  normal vecter  and the b
@@ -146,41 +146,41 @@
                     !         4: p is outside of the "trianble"
                     !         5: line is parallel to the plane
 
-       type(epPos)::  n, p
+      record /epPos/ n, p
       real*8 k
 
       integer::jcon 
 
       call ep3p2plane(p1, p2, p3, n, k)
       call epxpLandP(a, b, n, k, l, icon)
-!///////////////
-!      if(check == 1 ) then
-!         write(0,*) ' n, k=', n, k
-!         write(0,*) ' landP l,icon =',l, icon
-!      endif
-!/////////////
+c///////////////
+c      if(check == 1 ) then
+c         write(0,*) ' n, k=', n, k
+c         write(0,*) ' landP l,icon =',l, icon
+c      endif
+c/////////////
       if(icon <= 2) then
-         p%x = a%x + b%x*l
-         p%y = a%y + b%y*l
-         p%z = a%z + b%z*l
+         p.x = a.x + b.x*l
+         p.y = a.y + b.y*l
+         p.z = a.z + b.z*l
          call episPin3(p1, p2, p3, n, p, icon, jcon)
-!///////////
-!         if(check == 1 ) then
-!            write(0,*) 'xp =',p
-!            write(0,*) 'Pin3 icon, jcon =', icon, jcon
-!         endif
-!////////////
-!
-!      integer icon  ! output. 0: p is inside of the triangle formed by p1,2,3.
-!                    !         1: p is on the line, p1-p2.
-!                    !         2: p is on the p2-p3  line
-!                    !         3: p is on the p3-p1 line. 
-!                    !         4: p is outside of the triangle.
-!     integer jcon  ! output. has meaning only if icon =1~3.
-!                    !         0--> the point is not on the vertex
-!                    !         1--> p = p1
-!                    !         2--> p = p2
-!                    !         3--> p = p3 
+c///////////
+c         if(check == 1 ) then
+c            write(0,*) 'xp =',p
+c            write(0,*) 'Pin3 icon, jcon =', icon, jcon
+c         endif
+c////////////
+c
+c      integer icon  ! output. 0: p is inside of the triangle formed by p1,2,3.
+c                    !         1: p is on the line, p1-p2.
+c                    !         2: p is on the p2-p3  line
+c                    !         3: p is on the p3-p1 line. 
+c                    !         4: p is outside of the triangle.
+c     integer jcon  ! output. has meaning only if icon =1~3.
+c                    !         0--> the point is not on the vertex
+c                    !         1--> p = p1
+c                    !         2--> p = p2
+c                    !         3--> p = p3 
          if( icon <= 3 ) then
             call epscalerProd(n, b, towhich)
          else
@@ -194,10 +194,10 @@
       subroutine epxpLandP(a, b, n, k, l, icon)
       implicit none
 #include "ZepPos.h"
-!        get a crossing point of a half line with a given plane.
-       type(epPos)::  a  ! input.  starting point of the half line
-       type(epPos)::  b  ! input.  direction cos of the line |b| =1
-       type(epPos)::  n  ! input   normal vector of the plane 
+c        get a crossing point of a half line with a given plane.
+      record /epPos/ a  ! input.  starting point of the half line
+      record /epPos/ b  ! input.  direction cos of the line |b| =1
+      record /epPos/ n  ! input   normal vector of the plane 
       real*8  k         ! input.  n.x=k where x is any point on the plane
       real*8  l         ! output. a+lb is the crossing point.  
       integer icon      ! output. 0: crossing point obtained. (l>=0)
@@ -233,11 +233,11 @@
       subroutine episPin3(p1, p2, p3, n, p, icon, jcon)
       implicit none
 #include "ZepPos.h"
-       type(epPos)::  p1 ! input.  p1,p2,p3 are  non 
-       type(epPos)::  p2 ! input. colinear points
-       type(epPos)::  p3 ! input. to form a plane
-       type(epPos)::  n  ! input. normal vector of the plane
-       type(epPos)::  p  ! input given point which is on the plane fomred by
+      record /epPos/ p1 ! input.  p1,p2,p3 are  non 
+      record /epPos/ p2 ! input. colinear points
+      record /epPos/ p3 ! input. to form a plane
+      record /epPos/ n  ! input. normal vector of the plane
+      record /epPos/ p  ! input given point which is on the plane fomred by
                         !  three points p1, p2, p3
 
       integer icon  ! output. 0: p is inside of the triangle formed by p1,2,3.
@@ -257,37 +257,37 @@
       fxy(a1, b1, a2, b2, u, v) = (v-b1)*(a2-a1) - (u -a1)*(b2-b1)
       
 
-      nmax = max(abs(n%x), abs(n%y), abs(n%z))
-      if(nmax .eq. abs(n%x)) then
-!             use projection on to y-z plane
-         x1 = p1%y
-         y1 = p1%z
-         x2 = p2%y
-         y2 = p2%z
-         x3 = p3%y
-         y3 = p3%z
-         x = p%y
-         y = p%z
-      elseif(nmax .eq. abs(n%y)) then
-!            use projection on to x-z plane
-         x1 = p1%x
-         y1 = p1%z
-         x2 = p2%x
-         y2 = p2%z
-         x3 = p3%x
-         y3 = p3%z
-         x = p%x
-         y = p%z
+      nmax = max(abs(n.x), abs(n.y), abs(n.z))
+      if(nmax .eq. abs(n.x)) then
+c             use projection on to y-z plane
+         x1 = p1.y
+         y1 = p1.z
+         x2 = p2.y
+         y2 = p2.z
+         x3 = p3.y
+         y3 = p3.z
+         x = p.y
+         y = p.z
+      elseif(nmax .eq. abs(n.y)) then
+c            use projection on to x-z plane
+         x1 = p1.x
+         y1 = p1.z
+         x2 = p2.x
+         y2 = p2.z
+         x3 = p3.x
+         y3 = p3.z
+         x = p.x
+         y = p.z
       else
-!             use projection on to x-y plane
-         x1  =p1%x
-         y1 = p1%y
-         x2  =p2%x
-         y2 = p2%y
-         x3  =p3%x
-         y3 = p3%y
-         x  =p%x
-         y = p%y
+c             use projection on to x-y plane
+         x1  =p1.x
+         y1 = p1.y
+         x2  =p2.x
+         y2 = p2.y
+         x3  =p3.x
+         y3 = p3.y
+         x  =p.x
+         y = p.y
       endif
 
       p12 = fxy( x1, y1, x2, y2, x, y)
@@ -318,7 +318,7 @@
                   icon = 4
                endif
             else
-!                 p23 = 0
+c                 p23 = 0
                if( (x .ge. min(x2,x3) .and. x .le. max(x2,x3))
      *             .and.
      *          (y .ge. min(y2, y3) .and. y .le. max(y2, y3))) then
@@ -336,7 +336,7 @@
          icon = 4
          goto 100
       elseif(temp .eq. 0.) then
-!            p31 should be 0         
+c            p31 should be 0         
          icon =3
          if( (x .ge. min(x1,x3) .and. x .le. max(x1,x3))
      *             .and.
@@ -359,12 +359,12 @@
       subroutine episPin4(p1, p2, p3, p4, n, p, icon, jcon)
       implicit none
 #include "ZepPos.h"
-       type(epPos)::  p1 ! input.  p1,p2,p3,p4 form a "square" plane.
-       type(epPos)::  p2 ! input.  any 3 of which are not colinear
-       type(epPos)::  p3 ! input.  "square" may be skewed
-       type(epPos)::  p4 ! input.  2 of them may be the same.
-       type(epPos)::  n  ! input. normal vector of the plane
-       type(epPos)::  p  ! input given point which is on the plane fomred by
+      record /epPos/ p1 ! input.  p1,p2,p3,p4 form a "square" plane.
+      record /epPos/ p2 ! input.  any 3 of which are not colinear
+      record /epPos/ p3 ! input.  "square" may be skewed
+      record /epPos/ p4 ! input.  2 of them may be the same.
+      record /epPos/ n  ! input. normal vector of the plane
+      record /epPos/ p  ! input given point which is on the plane fomred by
                         !  three points p1, p2, p3, p4
 
       integer icon  ! output. 0: p is inside of the "square"
@@ -396,66 +396,66 @@
 
       subroutine ep3p2plane(p1, p2, p3, n, k)
       implicit none
-!        3 points to palne;
-!        get normal vector and const to represent a plane
-!        formed by a  three non-colinear points
-!
+c        3 points to palne;
+c        get normal vector and const to represent a plane
+c        formed by a  three non-colinear points
+c
 #include "ZepPos.h"
-       type(epPos)::  p1  ! input. first point
-       type(epPos)::  p2  ! input. second point
-       type(epPos)::  p3  ! input. 3rd point.  They should not be on a line.
-       type(epPos)::  n   ! output.a vector normal to the plane  formed by
+      record /epPos/ p1  ! input. first point
+      record /epPos/ p2  ! input. second point
+      record /epPos/ p3  ! input. 3rd point.  They should not be on a line.
+      record /epPos/ n   ! output.a vector normal to the plane  formed by
                          !      p1,p2,p3.. it is a unit vector (from v9.136) 
       real*8 k           ! output. const to represent the plane.
                          ! vec(n).vec(x) = k where x is any point on the plane.
 
-       type(epPos)::  p2p1, p3p2
-       type(epPos)::  p3p1
+      record /epPos/ p2p1, p3p2
+      record /epPos/ p3p1
       real(8):: norm
       call epdiff3vec(p2, p1, p2p1)
-!      call epdiff3vec(p3, p2, p3p2)
+c      call epdiff3vec(p3, p2, p3p2)
       call epdiff3vec(p3, p1, p3p1)
-!      call epvectorProd(p2p1, p3p2, n)
+c      call epvectorProd(p2p1, p3p2, n)
       call epvectorProd(p2p1, p3p1, n)
       call epscalerProd(n, n, norm)
       norm = sqrt(norm)
-      n%x = n%x/norm
-      n%y = n%y/norm
-      n%z = n%z/norm
+      n.x = n.x/norm
+      n.y = n.y/norm
+      n.z = n.z/norm
       call epscalerProd(n, p1, k)
       end
       
       subroutine epdiff3vec(p1, p2, p3)
       implicit none
 #include "ZepPos.h"
-       type(epPos)::  p1  ! input.  
-       type(epPos)::  p2  ! input.  
-       type(epPos)::  p3  ! output p3 = p1 - p2
+      record /epPos/ p1  ! input.  
+      record /epPos/ p2  ! input.  
+      record /epPos/ p3  ! output p3 = p1 - p2
 
-      p3%x = p1%x - p2%x
-      p3%y = p1%y - p2%y
-      p3%z = p1%z - p2%z
+      p3.x = p1.x - p2.x
+      p3.y = p1.y - p2.y
+      p3.z = p1.z - p2.z
       end
       subroutine epscalerProd(p1, p2, ans)
       implicit none
 #include "ZepPos.h"
-       type(epPos)::  p1  ! input.  
-       type(epPos)::  p2  ! input.  
+      record /epPos/ p1  ! input.  
+      record /epPos/ p2  ! input.  
       real*8 ans  ! output ans = p1.p2
 
-      ans = p1%x * p2%x + p1%y * p2%y +  p1%z * p2%z
+      ans = p1.x * p2.x + p1.y * p2.y +  p1.z * p2.z
       end
 
       subroutine epvectorProd(p1, p2, p3)
       implicit none
 #include "ZepPos.h"
-       type(epPos)::  p1  ! input.  
-       type(epPos)::  p2  ! input.  
-       type(epPos)::  p3  ! output. p1 x p2
+      record /epPos/ p1  ! input.  
+      record /epPos/ p2  ! input.  
+      record /epPos/ p3  ! output. p1 x p2
 
-      p3%x = p1%y*p2%z - p1%z* p2%y
-      p3%y = p1%z*p2%x - p1%x* p2%z
-      p3%z = p1%x*p2%y - p1%y* p2%x
+      p3.x = p1.y*p2.z - p1.z* p2.y
+      p3.y = p1.z*p2.x - p1.x* p2.z
+      p3.z = p1.x*p2.y - p1.y* p2.x
 
       end
       subroutine epwhichside(nm, k, p, diff)
