@@ -35,18 +35,8 @@ c           compute the minimum length to the boundary
          call epbsqpipe(comp, posl, dirl, length, icon)
       elseif(comp.struc(1:uscl) .eq. 'fpolygon') then
          call epbfpolygon(comp, posl, dirl, length, icon)
-      elseif(comp.struc(1:uscl) .eq. 'ocyl') then
-         call epbocyl(comp, posl, dirl, length, icon)
-      elseif(comp.struc(1:uscl) .eq. 'octagon') then
-         call epboctagon(comp, posl, dirl, length, icon)
-      elseif(comp.struc(1:uscl) .eq. 'horse') then
-         call epbhorse(comp, posl, dirl, length, icon)
-      elseif(comp.struc(1:uscl) .eq. 'oecyl') then
-         call epboecyl(comp, posl, dirl, length, icon)
-      elseif(comp.struc(1:uscl) .eq. 'honeycomb') then
-         call epbhoneycomb(comp, posl, dirl, length, icon)
-      elseif(comp.struc(1:uscl) .eq. 'fpolygon') then
-         call epbfpolygon(comp, posl, dirl, length, icon)
+      elseif(comp.struc(1:uscl) .eq. 'sqtccl') then
+         call epbsqtccl(comp, posl, dirl, length, icon)
 c---  elseif(comp.struc(1:uscl) .eq. '%2') then
 c---     call epb%2(comp, posl, dirl,  length, icon)
       else
@@ -86,18 +76,8 @@ c             see if pos is inside the comp component
          call epssqpipe(comp, pos, icon)
       elseif(comp.struc(1:uscl) .eq. 'fpolygon') then
          call epsfpolygon(comp, pos, icon)
-      elseif(comp.struc(1:uscl) .eq. 'ocyl') then
-         call epsocyl(comp, pos, icon)
-      elseif(comp.struc(1:uscl) .eq. 'octagon') then
-         call epsoctagon(comp, pos, icon)
-      elseif(comp.struc(1:uscl) .eq. 'horse') then
-         call epshorse(comp, pos, icon)
-      elseif(comp.struc(1:uscl) .eq. 'oecyl') then
-         call epsoecyl(comp, pos, icon)
-      elseif(comp.struc(1:uscl) .eq. 'honeycomb') then
-         call epshoneycomb(comp, pos, icon)
-      elseif(comp.struc(1:uscl) .eq. 'fpolygon') then
-         call epsfpolygon(comp, pos, icon)
+      elseif(comp.struc(1:uscl) .eq. 'sqtccl') then
+         call epssqtccl(comp, pos, icon)
 c---  elseif(comp.struc(1:uscl) .eq. '%2')  then
 c---     call eps%2(comp, pos, icon)
       else
@@ -132,18 +112,8 @@ c            read configuration data
          call eprsqpipe(comp)
       elseif(shape(1:uscl) .eq. 'fpolygon') then
          call eprfpolygon(comp)
-      elseif(shape(1:uscl) .eq. 'ocyl') then
-         call eprocyl(comp)
-      elseif(shape(1:uscl) .eq. 'octagon') then
-         call eproctagon(comp)
-      elseif(shape(1:uscl) .eq. 'horse') then
-         call eprhorse(comp)
-      elseif(shape(1:uscl) .eq. 'oecyl') then
-         call eproecyl(comp)
-      elseif(shape(1:uscl) .eq. 'honeycomb') then
-         call eprhoneycomb(comp)
-      elseif(shape(1:uscl) .eq. 'fpolygon') then
-         call eprfpolygon(comp)
+      elseif(shape(1:uscl) .eq. 'sqtccl') then
+         call eprsqtccl(comp)
 c---  elseif(shape(1:uscl)  .eq. '%2') then
 c---     call epr%2(comp)
       else
@@ -183,18 +153,8 @@ c
          call epenvlpsqpipe(comp, orig, abc)
       elseif(comp.struc(1:uscl) .eq. 'fpolygon') then
          call epenvlpfpolygon(comp, orig, abc)
-      elseif(comp.struc(1:uscl) .eq. 'ocyl') then
-         call epenvlpocyl(comp, orig, abc)
-      elseif(comp.struc(1:uscl) .eq. 'octagon') then
-         call epenvlpoctagon(comp, orig, abc)
-      elseif(comp.struc(1:uscl) .eq. 'horse') then
-         call epenvlphorse(comp, orig, abc)
-      elseif(comp.struc(1:uscl) .eq. 'oecyl') then
-         call epenvlpoecyl(comp, orig, abc)
-      elseif(comp.struc(1:uscl) .eq. 'honeycomb') then
-         call epenvlphoneycomb(comp, orig, abc)
-      elseif(comp.struc(1:uscl) .eq. 'fpolygon') then
-         call epenvlpfpolygon(comp, orig, abc)
+      elseif(comp.struc(1:uscl) .eq. 'sqtccl') then
+         call epenvlpsqtccl(comp, orig, abc)
 c---  elseif(comp.struc(1:uscl) .eq. '%2') then
 c---     call epenvlp%2(comp, orig, abc)
       else
@@ -233,18 +193,8 @@ c
          call epatlocsqpipe(comp, loc)
       elseif(comp.struc(1:uscl) .eq. 'fpolygon') then
          call epatlocfpolygon(comp, loc)
-      elseif(comp.struc(1:uscl) .eq. 'ocyl') then
-         call epatlococyl(comp, loc)
-      elseif(comp.struc(1:uscl) .eq. 'octagon') then
-         call epatlococtagon(comp, loc)
-      elseif(comp.struc(1:uscl) .eq. 'horse') then
-         call epatlochorse(comp, loc)
-      elseif(comp.struc(1:uscl) .eq. 'oecyl') then
-         call epatlocoecyl(comp, loc)
-      elseif(comp.struc(1:uscl) .eq. 'honeycomb') then
-         call epatlochoneycomb(comp, loc)
-      elseif(comp.struc(1:uscl) .eq. 'fpolygon') then
-         call epatlocfpolygon(comp, loc)
+      elseif(comp.struc(1:uscl) .eq. 'sqtccl') then
+         call epatlocsqtccl(comp, loc)
 c---  elseif(comp.struc(1:uscl) .eq. '%2') then
 c---     call epatloc%2(comp, loc)
       else
